pub enum FulfillmentAction {
Ship,
Hold,
}Expand description
FulfillmentAction : Specifies whether the fulfillment order should ship now or have an order hold put on it. Specifies whether the fulfillment order should ship now or have an order hold put on it.
Variants
Ship
Hold